==> 3.0.3.tar.gz: nextcloud-notes/l10n/hr.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Bilješke",
    "The last viewed note cannot be accessed. " : "Nije moguće pristupiti posljednje pregledanoj bilješci. ",
    "The notes folder is not accessible: %s" : "Mapa s bilješkama nije dostupna: %s",
    "Encryption Error" : "Pogreška šifriranja",
    "Error" : "Pogreška",
    "New note" : "Nova bilješka",
    "Distraction-free notes and writing" : "Bilješke i pisanje bez ometanja",
    "The Notes app is a distraction free notes taking app. It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [RESTful API](https://github.com/nextcloud/notes/wiki/API-0.2) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes) and [iOS](https://github.com/owncloud/notes-iOS-App) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikacija Bilješke omogućuje vam pisanje bilješki bez ometanja. Iskoristite njene kategorije za bolju organizaciju i mogućnosti oblikovanja koristeći sintaksu [Markdown](https://en.wikipedia.org/wiki/Markdown). Bilješke se spremaju kao datoteke u vašem Nextcloudu pa ih možete pregledati i uređivati sa svakim Nextcloudovim klijentom. Nadalje, zasebni [RESTful API](https://github.com/nextcloud/notes/wiki/API-0.2) omogućuje jednostavnu integraciju s aplikacijama trećih strana (trenutno postoje aplikacije za pisanje bilješki za [Android](https://github.com/stefan-niedermann/nextcloud-notes) i [iOS](https://github.com/owncloud/notes-iOS-App) koje omogućuju praktičan pristup vašim Nextcloudovim bilješkama). Dodatne značajke uključuju obilježavanje bilješki kao favorite.",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Postoje nespremljene bilješke. Ako napustite stranicu, odbacit ćete sve promjene!",
    "Settings" : "Postavke",
    "Folder to store your notes" : "Mapa za spremanje bilješki",
    "path to notes" : "put do bilješki",
    "File extension for new notes" : "Ekstenzija datoteke za nove bilješke",
    "All notes" : "Sve bilješke",
    "Categories" : "Kategorije",
    "Search result for “{search}” in {category}" : "Rezultat pretraživanja za „{search}” u {category}",
    "Search result for “{search}”" : "Rezultat pretraživanja za „{search}”",
    "No search result for “{search}” in {category}" : "Nema rezultata pretraživanja za „{search}” u {category}",
    "No search result for “{search}”" : "Nema rezultata pretraživanja za „{search}”",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "This week" : "Ovaj tjedan",
    "Last week" : "Prošli tjedan",
    "This month" : "Ovaj mjesec",
    "Last month" : "Prošli mjesec",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "Delete note" : "Izbriši bilješku",
    "Empty note" : "Prazna bilješka",
    "Write …" : "Napiši...",
    "Details" : "Pojedinosti",
    "Preview" : "Pretpregled",
    "Edit" : "Uredi",
    "Save failed. Click to retry." : "Spremanje nije uspjelo. Kliknite za ponovni pokušaj.",
    "Set category" : "Postavi kategoriju",
    "Category" : "Kategorija",
    "Uncategorized" : "Nekategorizirani",
    "Click here to save manually" : "Kliknite ovdje za ručno spremanje",
    "Saving failed!" : "Spremanje nije uspjelo!",
    "Last modified: {date}" : "Posljednja izmjena: {date}",
    "Note has unsaved changes" : "Bilješka ima nespremljene promjene",
    "Subcategory" : "Potkategorija",
    "_%n word_::_%n words_" : ["%n riječ","%n riječi","%n riječi"],
    "Write down your thoughts without any distractions." : "Zapišite svoje misli bez ometanja.",
    "Use Markdown markups to style your text." : "Za oblikovanje teksta upotrijebite oznake Markdown.",
    "Organize your notes in categories." : "Organizirajte svoje bilješke po kategorijama.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalirajte aplikaciju na svoj mobilni telefon kako biste s bilo kojeg mjesta mogli pristupiti svojim bilješkama.",
    "Android app" : "Aplikacija za Android",
    "iOS app" : "Aplikacija za iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Započnite pisati bilješku klikom na „{newnote}” u navigaciji aplikacije.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Možete kreirati potkategorije korištenjem \"/\" kao odjeljivača između nadređene kategorije i potkategorije, npr. “{parent}/{sub}”.",
    "See JavaScript console for details." : "Pojedinosti potražite u JavaScript konzoli.",
    "Updating settings has failed." : "Ažuriranje postavki nije uspjelo.",
    "Fetching notes has failed." : "Dohvaćanje bilješki nije uspjelo.",
    "Fetching note {id} has failed." : "Dohvaćanje bilješke {id} nije uspjelo.",
    "Creating new note has failed." : "Stvaranje nove bilješke nije uspjelo.",
    "Updating note {id} has failed." : "Ažuriranje bilješke {id} nije uspjelo.",
    "Deleting note {id} has failed." : "Brisanje bilješke {id} nije uspjelo.",
    "Toggling favorite for note {id} has failed." : "Postavljanje favorita za bilješku {id} nije uspjelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Ažuriranje kategorije bilješke nije uspjelo. Može li se pisati u ciljni direktorij?",
    "Updating the category for note {id} has failed." : "Ažuriranje kategorije za bilješku {id} nije uspjelo."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> 3.3.1.tar.gz: nextcloud-notes/l10n/hr.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Bilješke",
    "The last viewed note cannot be accessed. " : "Nije moguće pristupiti posljednje pregledanoj bilješci. ",
    "The notes folder is not accessible: %s" : "Mapa s bilješkama nije dostupna: %s",
    "Error" : "Pogreška",
    "New note" : "Nova bilješka",
    "Distraction-free notes and writing" : "Bilješke i pisanje bez ometanja",
    "Settings" : "Postavke",
    "Deleted {title}" : "Izbrisano {title}",
    "Deleted {number} notes" : "Izbrisane bilješke: {number}",
    "Undo Delete" : "Vrati izbrisano",
    "Please chose a valid path in {label} (bottom left corner)." : "Odaberite važeći put u {label} (donji lijevi kut).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Postoje nespremljene bilješke. Ako napustite stranicu, odbacit ćete sve promjene!",
    "Folder to store your notes" : "Mapa za spremanje bilješki",
    "path to notes" : "put do bilješki",
    "File extension for new notes" : "Ekstenzija datoteke za nove bilješke",
    "All notes" : "Sve bilješke",
    "Categories" : "Kategorije",
    "No search result for “{search}” in {category}" : "Nema rezultata pretraživanja za „{search}” u {category}",
    "No search result for “{search}”" : "Nema rezultata pretraživanja za „{search}”",
    "Loading …" : "Učitavanje…",
    "Search result for “{search}” in {category}" : "Rezultat pretraživanja za „{search}” u {category}",
    "Search result for “{search}”" : "Rezultat pretraživanja za „{search}”",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "This week" : "Ovaj tjedan",
    "Last week" : "Prošli tjedan",
    "This month" : "Ovaj mjesec",
    "Last month" : "Prošli mjesec",
    "Rename" : "Preimenuj",
    "Note's title" : "Naslov bilješke",
    "Delete note" : "Izbriši bilješku",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "Error during preparing note for deletion." : "Pogreška tijekom pripremanja bilješke za brisanje.",
    "Empty note" : "Prazna bilješka",
    "Write …" : "Napiši...",
    "Details" : "Pojedinosti",
    "Preview" : "Pretpregled",
    "Edit" : "Uredi",
    "Exit full screen" : "Zatvori prikaz preko cijelog zaslona",
    "Full screen" : "Prikaz preko cijelog zaslona",
    "Save failed. Click to retry." : "Spremanje nije uspjelo. Kliknite za ponovni pokušaj.",
    "Set category" : "Postavi kategoriju",
    "Category" : "Kategorija",
    "Uncategorized" : "Nekategorizirani",
    "Click here to save manually" : "Kliknite ovdje za ručno spremanje",
    "Saving failed!" : "Spremanje nije uspjelo!",
    "Last modified: {date}" : "Posljednja izmjena: {date}",
    "Note has unsaved changes" : "Bilješka ima nespremljene promjene",
    "Subcategory" : "Potkategorija",
    "_%n word_::_%n words_" : ["%n riječ","%n riječi","%n riječi"],
    "Write down your thoughts without any distractions." : "Zapišite svoje misli bez ometanja.",
    "Use Markdown markups to style your text." : "Za oblikovanje teksta upotrijebite oznake Markdown.",
    "Organize your notes in categories." : "Organizirajte svoje bilješke po kategorijama.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalirajte aplikaciju na svoj mobilni telefon kako biste s bilo kojeg mjesta mogli pristupiti svojim bilješkama.",
    "Android app" : "Aplikacija za Android",
    "iOS app" : "Aplikacija za iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Započnite pisati bilješku klikom na „{newnote}” u navigaciji aplikacije.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Možete kreirati potkategorije korištenjem \"/\" kao odjeljivača između nadređene kategorije i potkategorije, npr. “{parent}/{sub}”.",
    "See JavaScript console and server log for details." : "Pojedinosti potražite u JavaScript konzoli i zapisniku poslužitelja.",
    "Saving the note has failed due to insufficient storage." : "Spremanje bilješke nije uspjelo zbog nedovoljno prostora.",
    "Updating settings has failed." : "Ažuriranje postavki nije uspjelo.",
    "Fetching notes has failed." : "Dohvaćanje bilješki nije uspjelo.",
    "Fetching note {id} has failed." : "Dohvaćanje bilješke {id} nije uspjelo.",
    "Renaming note {id} has failed." : "Preimenovanje bilješke {id} nije uspjelo.",
    "Creating new note has failed." : "Stvaranje nove bilješke nije uspjelo.",
    "Updating note {id} has failed." : "Ažuriranje bilješke {id} nije uspjelo.",
    "Undo delete has failed for note {title}." : "Nije uspjelo vraćanje izbrisanog za bilješku {title}.",
    "Deleting note {id} has failed." : "Brisanje bilješke {id} nije uspjelo.",
    "Toggling favorite for note {id} has failed." : "Postavljanje favorita za bilješku {id} nije uspjelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Ažuriranje kategorije bilješke nije uspjelo. Može li se pisati u ciljni direktorij?",
    "Updating the category for note {id} has failed." : "Ažuriranje kategorije za bilješku {id} nije uspjelo.",
    "Development Mode" : "Razvojni način rada",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Čini se da je aplikacija za upravljanje bilješkama instalirana iz razvojnog izvora. Instalirajte je iz trgovine aplikacija <a href=\"%1$s\">Nextcloud App Store</a>. Ako želite sami izraditi aplikaciju Notes, slijedite <a href=“%2$s“>upute za razvojne inženjere</a>."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
